PlaceholderType

Enum PlaceholderType 

pub enum PlaceholderType {
Show 16 variants Title, Body, CenteredTitle, SubTitle, DateTime, SlideNumber, Footer, Header, Object, Chart, Table, ClipArt, Diagram, Media, SlideImage, Picture,
}
This simple type facilitates the storing of the content type a placeholder should contain.

Variants



Title

Contains a slide title. Allowed for Slide, Slide Layout and Slide Master. Can be horizontal or vertical on Slide and Slide Layout.



Body

Contains body text. Allowed for Slide, Slide Layout, Slide Master, Notes, Notes Master. Can be horizontal or vertical on Slide and Slide Layout.



CenteredTitle

Contains a title intended to be centered on the slide. Allowed for Slide and Slide Layout.



SubTitle

Contains a subtitle. Allowed for Slide and Slide Layout.



DateTime

Contains the date and time. Allowed for Slide, Slide Layout, Slide Master, Notes, Notes Master, Handout Master



SlideNumber

Contains the number of a slide. Allowed for Slide, Slide Layout, Slide Master, Notes, Notes Master, Handout Master



Footer

Contains text to be used as a footer in the document. Allowed for Slide, Slide Layout, Slide Master, Notes, Notes Master, Handout Master



Header

Contains text to be used as a header for the document. Allowed for Notes, Notes Master, Handout Master.



Object

Contains any content type. Special type. Allowed for Slide and Slide Layout.



Chart

Contains a chart or graph. Special type. Allowed for Slide and Slide Layout.



Table

Contains a table. Special type. Allowed for Slide and Slide Layout.



ClipArt

Contains a single clip art image. Special type. Allowed for Slide and Slide Layout.



Diagram

Contains a diagram. Special type. Allowed for Slide and Slide Layout.



Media

Contains multimedia content such as audio or a movie clip. Special type. Allowed for Slide and Slide Layout.



SlideImage

Contains an image of the slide. Allowed for Notes and Notes Master.



Picture

Contains a picture. Special type. Allowed for Slide and Slide Layout.