GraphicalObjectFrame

Struct GraphicalObjectFrame 

pub struct GraphicalObjectFrame {
    pub black_white_mode: Option<BlackWhiteMode>,
    pub non_visual_props: Box<GraphicalObjectFrameNonVisual>,
    pub transform: Box<Transform2D>,
    pub graphic: GraphicalObject,
}

Fields

black_white_mode: Option<BlackWhiteMode>

Specifies how the graphical object should be rendered, using color, black or white, or grayscale.

Note

This does not mean that the graphical object itself is stored with only black and white or grayscale information. This attribute instead sets the rendering mode that the graphical object uses.

non_visual_props: Box<GraphicalObjectFrameNonVisual>

This element specifies all non-visual properties for a graphic frame. This element is a container for the non-visual identification properties, shape properties and application properties that are to be associated with a graphic frame. This allows for additional information that does not affect the appearance of the graphic frame to be stored.

transform: Box<Transform2D>

This element specifies the transform to be applied to the corresponding graphic frame. This transformation is applied to the graphic frame just as it would be for a shape or group shape.

graphic: GraphicalObject

Implementations